==> clean-6.x-1.0.tar.gz: clean/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.1.2.5.2.1 2008/10/10 13:42:50 psynaptic Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">

<head>
  <title><?php print $head_title ?></title>
  <meta http-equiv="content-language" content="<?php print $language->language ?>" />
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <!--[if IE]>
    <link rel="stylesheet" href="<?php print $path ?>ie.css" type="text/css">
  <![endif]-->
  <!--[if lte IE 6]>
    <link rel="stylesheet" href="<?php print $path ?>ie6.css" type="text/css">
  <![endif]-->
</head>

<body class="layout-<?php print $body_classes ?>">
  <div id="page">

    <div id="header">
      <?php if ($header || $search_box): ?>
        <div id="header-right">
          <?php print $header ?>
          <?php print $search_box ?>
        </div>
      <?php endif ?>

      <a id="logo" href="<?php print url(); ?>"><span id="site-name"><?php print $site_name ?></span></a>
      <span id="slogan"><?php print $site_slogan ?></span>
    </div>

    <?php if ($primary_links): ?>
      <div id="navigation">
          <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
        <?php if ($secondary_links) : ?>
          <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')) ?>
        <?php endif ?>
      </div>
    <?php endif ?>

    <?php print $breadcrumb ?>

    <?php if ($left): ?>
      <div id="left" class="sidebar">
        <?php print $left ?>
      </div>
    <?php endif ?>

    <div id="centre">
      <?php print $messages ?>

      <?php if ($tabs): ?>
        <div class="tabs"><?php print $tabs ?></div>
      <?php endif ?>

      <?php if ($title): ?>
        <h1 class="page-title"><?php print $title ?></h1>
      <?php endif ?>

      <?php print $help ?>
      <?php print $content ?>
      <?php print $feed_icons ?>

    </div><!--// centre -->

    <?php if ($right): ?>
      <div id="right" class="sidebar">
        <?php print $right ?>
      </div>
    <?php endif ?>

    <?php if ($footer): ?>
      <div id="footer"><?php print $footer ?></div>
    <?php endif ?>

    <?php if ($footer_message): ?>
      <div id="footer-message"><?php print $footer_message ?></div>
    <?php endif ?>

  </div><!--// page -->
  <?php print $closure ?>
</body>
</html>

==> clean-6.x-1.1.tar.gz: clean/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.1.2.5.2.5 2008/11/13 15:33:07 psynaptic Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">

<head>
  <title><?php print $head_title ?></title>
  <meta http-equiv="content-language" content="<?php print $language->language ?>" />
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <!--[if IE]>
    <link rel="stylesheet" href="<?php print $path ?>ie.css" type="text/css">
  <![endif]-->
  <!--[if lte IE 6]>
    <link rel="stylesheet" href="<?php print $path ?>ie6.css" type="text/css">
  <![endif]-->
</head>

<body class="<?php print $body_classes ?>">
  <div id="page">

    <div id="header">
      <?php if ($header || $search_box): ?>
        <div id="header-right">
          <?php print $header ?>
          <?php print $search_box ?>
        </div>
      <?php endif ?>

      <?php if ($logo): ?>
        <a id="logo" href="<?php print $base_path ?>">
          <?php print theme('image', $logo) ?>
        </a>
      <?php endif ?>
      <?php if ($site_name): ?>
        <a id="site-name" href="<?php print $base_path ?>">
          <?php print $site_name ?>
        </a>
      <?php endif ?>
      <?php if ($site_slogan): ?>
        <span id="slogan"><?php print $site_slogan ?></span>
      <?php endif ?>
    </div>

    <?php if ($primary_links): ?>
      <div id="navigation">
          <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
        <?php if ($secondary_links) : ?>
          <?php print theme('links', $secondary_links, array('class' => 'links secondary-links')) ?>
        <?php endif ?>
      </div>
    <?php endif ?>

    <?php print $breadcrumb ?>

    <?php if ($left): ?>
      <div id="left" class="sidebar">
        <?php print $left ?>
      </div>
    <?php endif ?>

    <div id="centre">
      <?php print $messages ?>

      <?php if ($tabs): ?>
        <div class="tabs"><?php print $tabs ?></div>
      <?php endif ?>

      <?php if ($title): ?>
        <h1 class="page-title"><?php print $title ?></h1>
      <?php endif ?>

      <?php print $help ?>
      <?php print $content ?>
      <?php print $feed_icons ?>

    </div><!--// centre -->

    <?php if ($right): ?>
      <div id="right" class="sidebar">
        <?php print $right ?>
      </div>
    <?php endif ?>

    <?php if ($footer): ?>
      <div id="footer"><?php print $footer ?></div>
    <?php endif ?>

    <?php if ($footer_message): ?>
      <div id="footer-message"><?php print $footer_message ?></div>
    <?php endif ?>

  </div><!--// page -->
  <?php print $closure ?>
</body>
</html>
